@@ -92,14 +92,14 @@ class Venue():
 
     def get_acts(self):
         """get this Venue's Acts and find out about them"""
+        from backstage.shortcuts import Act
         self.acts = []
         acts_root = os.path.abspath(os.path.join(self.VENUE_ROOT,'acts'))
         acts_list = os.listdir(acts_root)
         for a in acts_list:
             try:
-                pass
-                #act=Act(self,a)
-                #self.acts.append(act)
+                act=Act(self,a)
+                self.acts.append(act)
             except:
                 pass
 
